changeset 1276:a3abaabac98e

Missed a bit of the name change.
author Rob Landley <rob@landley.net>
date Sun, 07 Nov 2010 15:57:32 -0600
parents a4cb2ed0a551
children 6357653d921e
files more/build-control-images.sh
diffstat 1 files changed, 3 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/more/build-control-images.sh	Sun Nov 07 15:55:26 2010 -0600
+++ b/more/build-control-images.sh	Sun Nov 07 15:57:32 2010 -0600
@@ -6,12 +6,12 @@
 
 blank_tempdir build/control-images
 
 # Iterate through sources/native-builds and run each script, writing output
 # to build/control-images/$SCRIPTNAME.hdc
 
-for i in sources/native-builds/{*.sh,*/make-control-image.sh}
+for i in sources/control-images/{*.sh,*/make-control-image.sh}
 do
-  SCRIPTNAME=$(echo $i | sed 's@sources/native-builds/\([^./]*\).*@\1@')
+  SCRIPTNAME=$(echo $i | sed 's@sources/control-images/\([^./]*\).*@\1@')
   # Forking doesn't work yet due to extract collisions with the same package
   #maybe_fork "$i build/control-images/$SCRIPTNAME.hdc | maybe_quiet"
   $i build/control-images/$SCRIPTNAME.hdc | maybe_quiet
@@ -6,12 +6,12 @@
 blank_tempdir build/control-images
 
-# Iterate through sources/native-builds and run each script, writing output
+# Iterate through sources/control-images and run each script, writing output
 # to build/control-images/$SCRIPTNAME.hdc
 